# YouTube to Docs

Process YouTube videos into transcripts, summaries, Q&A, infographics, and more.

GitHub

## Configuration

YouTube URL or Video ID
Model Suite
Output File
Show advanced options
Summary Model
Transcript Source
Text-To-Speech Model
Infographic Model
Alt Text Model
Translate
Suggest Corrected Captions
Post Process (JSON)
Combine infographic + audio
Skip YouTube summary
Verbose output
Processing...

## Artifacts